@@ -1,12 +1,13 @@
 import asyncio
 import contextlib
+import dataclasses
 import logging
 import shlex
 import sys
 import uuid
 import webbrowser
-from datetime import datetime
-from typing import List, Optional, Sequence, Set, Tuple
+from datetime import datetime, timedelta, timezone
+from typing import AsyncIterator, List, Optional, Sequence, Set, Tuple
 
 import async_timeout
 import click
@@ -27,7 +28,13 @@ from neuro_sdk import (
 )
 
 from neuro_cli.formatters.images import DockerImageProgress
-from neuro_cli.formatters.utils import URIFormatter, image_formatter, uri_formatter
+from neuro_cli.formatters.utils import (
+    URIFormatter,
+    get_datetime_formatter,
+    image_formatter,
+    uri_formatter,
+)
+from neuro_cli.utils import resolve_disk
 
 from .ael import process_attach, process_exec, process_logs
 from .click_types import (
@@ -52,6 +59,7 @@ from .parse_utils import (
     get_default_columns,
     parse_columns,
     parse_timedelta,
+    serialize_timedelta,
 )
 from .root import Root
 from .utils import (
@@ -73,6 +81,9 @@ STORAGE_MOUNTPOINT = "/var/storage"
 
 DEFAULT_JOB_LIFE_SPAN = "1d"
 
+TOP_REFRESH_DELAY = 0.2
+TOP_NEW_JOBS_DELAY = 3
+
 
 TTY_OPT = option(
     "-t/-T",
@@ -272,6 +283,18 @@ async def attach(root: Root, job: str, port_forward: List[Tuple[int, int]]) -> N
     secure=True,
 )
 @option("-n", "--name", metavar="NAME", help="Filter out jobs by name.", secure=True)
+@option(
+    "--distinct",
+    is_flag=True,
+    default=False,
+    help="Show only first job if names are same.",
+)
+@option(
+    "--recent-first/--recent-last",
+    is_flag=True,
+    default=False,
+    help="Show newer jobs first or last",
+)
 @option(
     "-t",
     "--tag",
@@ -324,6 +347,8 @@ async def ls(
     status: Sequence[str],
     all: bool,
     name: str,
+    distinct: bool,
+    recent_first: bool,
     tag: Sequence[str],
     owner: Sequence[str],
     since: str,
@@ -361,12 +386,28 @@ async def ls(
         tags=tags,
         since=_parse_date(since),
         until=_parse_date(until),
+        reverse=recent_first,
     )
 
     # client-side filtering
     if description:
         jobs = (job async for job in jobs if job.description == description)
 
+    if distinct:
+
+        async def _filter_distinct(
+            jobs_iter: AsyncIterator[JobDescription],
+        ) -> AsyncIterator[JobDescription]:
+            names: Set[str] = set()
+            async for job in jobs_iter:
+                if job.name in names:
+                    continue
+                if job.name is not None:
+                    names.add(job.name)
+                yield job
+
+        jobs = _filter_distinct(jobs)
+
     uri_fmtr: URIFormatter
     if full_uri:
         uri_fmtr = str
@@ -379,7 +420,10 @@ async def ls(
     else:
         image_fmtr = image_formatter(uri_formatter=uri_fmtr)
         formatter = TabularJobsFormatter(
-            root.client.username, format, image_formatter=image_fmtr
+            root.client.username,
+            format,
+            image_formatter=image_fmtr,
+            datetime_formatter=get_datetime_formatter(root.iso_datetime_format),
         )
 
     with root.pager():
@@ -406,10 +450,15 @@ async def status(root: Root, job: str, full_uri: bool) -> None:
         uri_fmtr = uri_formatter(
             username=root.client.username, cluster_name=root.client.cluster_name
         )
-    root.print(JobStatusFormatter(uri_formatter=uri_fmtr)(res))
+    root.print(
+        JobStatusFormatter(
+            uri_formatter=uri_fmtr,
+            datetime_formatter=get_datetime_formatter(root.iso_datetime_format),
+        )(res)
+    )
 
 
-@command()
+@command(deprecated=True, hidden=True)
 async def tags(root: Root) -> None:
     """
     List all tags submitted by the user.
@@ -435,7 +484,7 @@ async def browse(root: Root, job: str) -> None:
 
 
 @command()
-@argument("job", type=JOB)
+@argument("jobs", nargs=-1, required=False, type=JOB)
 @option(
     "--timeout",
     default=0,
@@ -443,15 +492,65 @@ async def browse(root: Root, job: str) -> None:
     show_default=True,
     help="Maximum allowed time for executing the command, 0 for no timeout",
 )
-async def top(root: Root, job: str, timeout: float) -> None:
+async def top(root: Root, jobs: Sequence[str], timeout: float) -> None:
     """
     Display GPU/CPU/Memory usage.
     """
-    with JobTelemetryFormatter(root.console) as formatter:
-        id = await resolve_job(job, client=root.client, status=JobStatus.active_items())
+    observed: Set[str] = set()
+
+    async def create_pollers() -> None:
+        if jobs:
+            for job_str in jobs:
+                job_id = await resolve_job(
+                    job_str, client=root.client, status=JobStatus.active_items()
+                )
+                if job_id in observed:
+                    continue
+                observed.add(job_id)
+                job = await root.client.jobs.status(job_id)
+                asyncio.create_task(poller(job))
+        else:
+            since: Optional[datetime] = None
+            while True:
+                jobs2 = root.client.jobs.list(
+                    statuses=JobStatus.active_items(),
+                    owners=(root.client.username,),
+                    since=since,
+                )
+                dt: Optional[datetime]
+                dt = datetime.now(timezone.utc) - timedelta(minutes=1)
+                if since is None or since < dt:
+                    since = dt
+                async for job in jobs2:
+                    job_id = job.id
+                    if job_id in observed:
+                        continue
+                    observed.add(job_id)
+                    dt = job.history.created_at
+                    if dt is not None and since < dt:
+                        since = dt
+                    asyncio.create_task(poller(job))
+                await asyncio.sleep(TOP_NEW_JOBS_DELAY)
+
+    async def poller(job: JobDescription) -> None:
+        async for info in root.client.jobs.top(job.id):
+            formatter.update(job, info)
+            await asyncio.sleep(0)
+        formatter.remove(job.id)
+        await asyncio.sleep(0)
+
+    async def renderer() -> None:
         async with async_timeout.timeout(timeout if timeout else None):
-            async for res in root.client.jobs.top(id):
-                formatter.update(res)
+            while True:
+                if formatter.changed:
+                    formatter.render()
+                await asyncio.sleep(TOP_REFRESH_DELAY)
+
+    with JobTelemetryFormatter(
+        root.console,
+        datetime_formatter=get_datetime_formatter(root.iso_datetime_format),
+    ) as formatter:
+        await asyncio.gather(create_pollers(), renderer())
 
 
 @command()
@@ -775,7 +874,29 @@ async def run(
     )
 
 
+@command()
+@argument("job", type=JOB)
+async def generate_run_command(root: Root, job: str) -> None:
+    """
+    Generate command that will rerun given job.
+
+    Examples:
+
+    # You can use the following to directly re-execute it:
+    eval $(neuro job generate-run-command <job-id>)
+    """
+    id = await resolve_job(
+        job,
+        client=root.client,
+        status=JobStatus.items(),
+    )
+    job_description = await root.client.jobs.status(id)
+    args = _job_to_cli_args(job_description)
+    root.print(f"neuro run " + " ".join(args))
+
+
 job.add_command(run)
+job.add_command(generate_run_command)
 job.add_command(ls)
 job.add_command(status)
 job.add_command(tags)
@@ -864,7 +985,18 @@ async def run_job(
     volume_parse_result = root.client.parse.volumes(volume)
     volumes = list(volume_parse_result.volumes)
     secret_files = volume_parse_result.secret_files
-    disk_volumes = volume_parse_result.disk_volumes
+
+    # Replace disk names with disk ids
+    async def _force_disk_id(disk_uri: URL) -> URL:
+        disk_id = await resolve_disk(disk_uri.parts[-1], client=root.client)
+        return disk_uri / f"../{disk_id}"
+
+    disk_volumes = [
+        dataclasses.replace(
+            disk_volume, disk_uri=await _force_disk_id(disk_volume.disk_uri)
+        )
+        for disk_volume in volume_parse_result.disk_volumes
+    ]
 
     if pass_config:
         env_name = PASS_CONFIG_ENV_NAME
@@ -1026,3 +1158,68 @@ def _check_tty(root: Root, tty: bool) -> None:
             "The operation should be executed from a terminal, "
             "the input device is not a TTY"
         )
+
+
+def _job_to_cli_args(job: JobDescription) -> List[str]:
+    res = []
+    if job.preset_name:
+        res += ["--preset", job.preset_name]
+    else:
+        log.warning("Cannot determine preset name used to run job")
+    if not job.container.resources.shm:
+        res += ["--no-extshm"]
+    if job.container.http:
+        if job.container.http.port != 80:
+            res += ["--http", str(job.container.http.port)]
+        if not job.container.http.requires_auth:
+            res += ["--no-http-auth"]
+    if job.name:
+        res += ["--name", job.name]
+    for tag in job.tags:
+        res += ["--tag", tag]
+    if job.description:
+        res += ["--description", shlex.quote(job.description)]
+    for volume in job.container.volumes:
+        res += [
+            "--volume",
+            (
+                f"{volume.storage_uri}:{volume.container_path}"
+                f":{'ro' if volume.read_only else 'rw'}"
+            ),
+        ]
+    for disk in job.container.disk_volumes:
+        res += [
+            "--volume",
+            f"{disk.disk_uri}:{disk.container_path}:{'ro' if disk.read_only else 'rw'}",
+        ]
+    for secret in job.container.secret_files:
+        res += ["--volume", f"{secret.secret_uri}:{secret.container_path}"]
+    if job.container.entrypoint:
+        res += ["--entrypoint", job.container.entrypoint]
+    if job.container.working_dir:
+        res += ["--workdir", job.container.working_dir]
+    for env_name, env_value in job.container.env.items():
+        if env_name == PASS_CONFIG_ENV_NAME and job.pass_config:
+            continue  # Do not specify value for pass config env variable
+        res += ["--env", f"{env_name}={env_value}"]
+    for env_name, secret_uri in job.container.secret_env.items():
+        res += ["--env", f"{env_name}={secret_uri}"]
+    if job.restart_policy == JobRestartPolicy.ALWAYS:
+        res += ["--restart", str(JobRestartPolicy.ALWAYS)]
+    if job.restart_policy == JobRestartPolicy.ON_FAILURE:
+        res += ["--restart", str(JobRestartPolicy.ON_FAILURE)]
+    if job.life_span:
+        res += ["--life-span", serialize_timedelta(timedelta(seconds=job.life_span))]
+    if job.schedule_timeout:
+        res += [
+            "--schedule-timeout",
+            serialize_timedelta(timedelta(seconds=job.schedule_timeout)),
+        ]
+    if job.pass_config:
+        res += ["--pass-config"]
+    if job.privileged:
+        res += ["--privileged"]
+    res += [str(job.container.image)]
+    if job.container.command:
+        res += [job.container.command]
+    return res
