@@ -1,11 +1,10 @@
-import asyncio
 import dataclasses
 import io
 import logging
 from collections import namedtuple
 from difflib import ndiff
 from pathlib import Path
-from typing import Any, AsyncIterator, Callable, DefaultDict, List, Optional, Set, Union
+from typing import Any, Callable, DefaultDict, Iterator, List, Optional, Set, Union
 
 import click
 import pytest
@@ -51,6 +50,7 @@ def nmrc_path(tmp_path: Path, token: str, auth_config: _AuthConfig) -> Path:
         auth_config=auth_config,
         auth_token=_AuthToken.create_non_expiring(token),
         url=URL("https://dev.neu.ro/api/v1"),
+        admin_url=URL("https://dev.neu.ro/apis/admin/v1"),
         version=__version__,
         cluster_name="default",
         clusters={cluster_config.name: cluster_config},
@@ -69,29 +69,30 @@ def create_root(config_path: Path) -> Root:
         verbosity=0,
         trace=False,
         trace_hide_token=True,
+        force_trace_all=False,
         command_path="",
         command_params=[],
         skip_gmp_stats=True,
         show_traceback=False,
+        iso_datetime_format=False,
     )
 
 
 @pytest.fixture()
-async def root(nmrc_path: Path, loop: asyncio.AbstractEventLoop) -> AsyncIterator[Root]:
+def root(nmrc_path: Path) -> Iterator[Root]:
     root = create_root(config_path=nmrc_path)
-    await root.init_client()
+    root.run(root.init_client())
     yield root
-    await root.client.close()
+    root.close()
 
 
 @pytest.fixture()
-async def root_no_logged_in(
-    tmp_path: Path, loop: asyncio.AbstractEventLoop
-) -> AsyncIterator[Root]:
+def root_no_logged_in(tmp_path: Path) -> Iterator[Root]:
     root = create_root(config_path=tmp_path)
     assert root._client is None
     yield root
     assert root._client is None
+    root.close()
 
 
 @pytest.fixture()
@@ -139,7 +140,9 @@ class Guard:
     def __eq__(self, other: object) -> bool:
         if not isinstance(other, Guard):
             return NotImplemented
-        return self.arg == other.arg
+        return [s.rstrip() for s in self.arg.splitlines()] == [
+            s.rstrip() for s in other.arg.splitlines()
+        ]
 
 
 class RichComparator:
@@ -209,7 +212,7 @@ class RichComparator:
             orig = self.read_ref(ref)
             tmp = ref.with_suffix(".orig")
             self.write_file(tmp, buf)
-            # reading from file is important, fil writer replaces \r with \n
+            # reading from file is important, file writer replaces \r with \n
             actual = self.read_file(tmp)
             assert Guard(actual, tmp) == Guard(orig, ref)
 
