@@ -1,6 +1,7 @@
 import io
 import itertools
 import sys
+from dataclasses import replace
 from datetime import datetime, timedelta, timezone
 from typing import Any, Callable, Optional
 
@@ -24,6 +25,7 @@ from neuro_sdk import (
     SecretFile,
     Volume,
 )
+from neuro_sdk.jobs import JobStatusItem
 from neuro_sdk.parsing_utils import _ImageNameParser
 
 from neuro_cli.formatters.jobs import (
@@ -35,10 +37,15 @@ from neuro_cli.formatters.jobs import (
     TabularJobsFormatter,
     format_timedelta,
 )
-from neuro_cli.formatters.utils import image_formatter, uri_formatter
+from neuro_cli.formatters.utils import (
+    format_datetime_human,
+    image_formatter,
+    uri_formatter,
+)
 from neuro_cli.parse_utils import parse_columns
 
 TEST_JOB_ID = "job-ad09fe07-0c64-4d32-b477-3b737d215621"
+TEST_JOB_ID2 = "job-3f9c5f93-45be-4c5d-acbd-11c68260235f"
 TEST_JOB_NAME = "test-job-name"
 
 _NewConsole = Callable[..., Console]
@@ -274,7 +281,11 @@ class TestJobOutputFormatter:
         )
 
         uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
-        rich_cmp(JobStatusFormatter(uri_formatter=uri_fmtr)(description))
+        rich_cmp(
+            JobStatusFormatter(
+                uri_formatter=uri_fmtr, datetime_formatter=format_datetime_human
+            )(description)
+        )
 
     def test_job_with_tags(self, rich_cmp: Any) -> None:
         description = JobDescription(
@@ -306,7 +317,11 @@ class TestJobOutputFormatter:
         )
 
         uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
-        rich_cmp(JobStatusFormatter(uri_formatter=uri_fmtr)(description))
+        rich_cmp(
+            JobStatusFormatter(
+                uri_formatter=uri_fmtr, datetime_formatter=format_datetime_human
+            )(description)
+        )
 
     def test_job_with_tags_wrap_tags(self, rich_cmp: Any) -> None:
         description = JobDescription(
@@ -338,7 +353,11 @@ class TestJobOutputFormatter:
         )
 
         uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
-        rich_cmp(JobStatusFormatter(uri_formatter=uri_fmtr)(description))
+        rich_cmp(
+            JobStatusFormatter(
+                uri_formatter=uri_fmtr, datetime_formatter=format_datetime_human
+            )(description)
+        )
 
     def test_job_with_life_span_with_value(self, rich_cmp: Any) -> None:
         description = JobDescription(
@@ -370,7 +389,11 @@ class TestJobOutputFormatter:
         )
 
         uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
-        rich_cmp(JobStatusFormatter(uri_formatter=uri_fmtr)(description))
+        rich_cmp(
+            JobStatusFormatter(
+                uri_formatter=uri_fmtr, datetime_formatter=format_datetime_human
+            )(description)
+        )
 
     def test_job_with_life_span_without_value(self, rich_cmp: Any) -> None:
         description = JobDescription(
@@ -402,7 +425,11 @@ class TestJobOutputFormatter:
         )
 
         uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
-        rich_cmp(JobStatusFormatter(uri_formatter=uri_fmtr)(description))
+        rich_cmp(
+            JobStatusFormatter(
+                uri_formatter=uri_fmtr, datetime_formatter=format_datetime_human
+            )(description)
+        )
 
     def test_job_with_restart_policy(self, rich_cmp: Any) -> None:
         description = JobDescription(
@@ -435,7 +462,11 @@ class TestJobOutputFormatter:
         )
 
         uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
-        rich_cmp(JobStatusFormatter(uri_formatter=uri_fmtr)(description))
+        rich_cmp(
+            JobStatusFormatter(
+                uri_formatter=uri_fmtr, datetime_formatter=format_datetime_human
+            )(description)
+        )
 
     def test_pending_job(self, rich_cmp: Any) -> None:
         description = JobDescription(
@@ -466,7 +497,11 @@ class TestJobOutputFormatter:
         )
 
         uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
-        rich_cmp(JobStatusFormatter(uri_formatter=uri_fmtr)(description))
+        rich_cmp(
+            JobStatusFormatter(
+                uri_formatter=uri_fmtr, datetime_formatter=format_datetime_human
+            )(description)
+        )
 
     def test_pending_job_no_reason(self, rich_cmp: Any) -> None:
         description = JobDescription(
@@ -494,7 +529,11 @@ class TestJobOutputFormatter:
         )
 
         uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
-        rich_cmp(JobStatusFormatter(uri_formatter=uri_fmtr)(description))
+        rich_cmp(
+            JobStatusFormatter(
+                uri_formatter=uri_fmtr, datetime_formatter=format_datetime_human
+            )(description)
+        )
 
     def test_pending_job_with_reason(self, rich_cmp: Any) -> None:
         description = JobDescription(
@@ -523,7 +562,11 @@ class TestJobOutputFormatter:
         )
 
         uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
-        rich_cmp(JobStatusFormatter(uri_formatter=uri_fmtr)(description))
+        rich_cmp(
+            JobStatusFormatter(
+                uri_formatter=uri_fmtr, datetime_formatter=format_datetime_human
+            )(description)
+        )
 
     def test_pending_job_no_description(self, rich_cmp: Any) -> None:
         description = JobDescription(
@@ -551,7 +594,11 @@ class TestJobOutputFormatter:
         )
 
         uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
-        rich_cmp(JobStatusFormatter(uri_formatter=uri_fmtr)(description))
+        rich_cmp(
+            JobStatusFormatter(
+                uri_formatter=uri_fmtr, datetime_formatter=format_datetime_human
+            )(description)
+        )
 
     def test_running_job(self, rich_cmp: Any) -> None:
         description = JobDescription(
@@ -581,7 +628,66 @@ class TestJobOutputFormatter:
         )
 
         uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
-        rich_cmp(JobStatusFormatter(uri_formatter=uri_fmtr)(description))
+        rich_cmp(
+            JobStatusFormatter(
+                uri_formatter=uri_fmtr, datetime_formatter=format_datetime_human
+            )(description)
+        )
+
+    def test_running_job_with_status_items(self, rich_cmp: Any) -> None:
+        description = JobDescription(
+            status=JobStatus.RUNNING,
+            owner="test-user",
+            cluster_name="default",
+            id="test-job",
+            uri=URL("job://default/test-user/test-job"),
+            description="test job description",
+            history=JobStatusHistory(
+                status=JobStatus.RUNNING,
+                reason="ContainerRunning",
+                description="",
+                created_at=isoparse("2018-09-25T12:28:21.298672+00:00"),
+                started_at=isoparse("2018-09-25T12:28:24.759433+00:00"),
+                finished_at=None,
+                transitions=[
+                    JobStatusItem(
+                        status=JobStatus.PENDING,
+                        transition_time=isoparse("2018-09-25T12:28:21.298672+00:00"),
+                        reason="Creating",
+                    ),
+                    JobStatusItem(
+                        status=JobStatus.PENDING,
+                        transition_time=isoparse("2018-09-25T12:28:22.298672+00:00"),
+                        reason="Scheduling",
+                    ),
+                    JobStatusItem(
+                        status=JobStatus.PENDING,
+                        transition_time=isoparse("2018-09-25T12:28:23.298672+00:00"),
+                        reason="ContainerCreating",
+                    ),
+                    JobStatusItem(
+                        status=JobStatus.RUNNING,
+                        transition_time=isoparse("2018-09-25T12:28:24.759433+00:00"),
+                    ),
+                ],
+            ),
+            http_url=URL("http://local.host.test/"),
+            container=Container(
+                command="test-command",
+                image=RemoteImage.new_external_image(name="test-image"),
+                resources=Resources(16, 0.1, 0, None, False, None, None),
+            ),
+            scheduler_enabled=False,
+            pass_config=True,
+            internal_hostname="host.local",
+        )
+
+        uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
+        rich_cmp(
+            JobStatusFormatter(
+                uri_formatter=uri_fmtr, datetime_formatter=format_datetime_human
+            )(description)
+        )
 
     def test_running_named_job(self, rich_cmp: Any) -> None:
         description = JobDescription(
@@ -613,7 +719,11 @@ class TestJobOutputFormatter:
         )
 
         uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
-        rich_cmp(JobStatusFormatter(uri_formatter=uri_fmtr)(description))
+        rich_cmp(
+            JobStatusFormatter(
+                uri_formatter=uri_fmtr, datetime_formatter=format_datetime_human
+            )(description)
+        )
 
     def test_job_with_entrypoint(self, rich_cmp: Any) -> None:
         description = JobDescription(
@@ -644,7 +754,11 @@ class TestJobOutputFormatter:
         )
 
         uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
-        rich_cmp(JobStatusFormatter(uri_formatter=uri_fmtr)(description))
+        rich_cmp(
+            JobStatusFormatter(
+                uri_formatter=uri_fmtr, datetime_formatter=format_datetime_human
+            )(description)
+        )
 
     def test_job_with_environment(self, rich_cmp: Any) -> None:
         description = JobDescription(
@@ -683,7 +797,11 @@ class TestJobOutputFormatter:
         )
 
         uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
-        rich_cmp(JobStatusFormatter(uri_formatter=uri_fmtr)(description))
+        rich_cmp(
+            JobStatusFormatter(
+                uri_formatter=uri_fmtr, datetime_formatter=format_datetime_human
+            )(description)
+        )
 
     def test_job_with_volumes_short(self, rich_cmp: Any) -> None:
         description = JobDescription(
@@ -738,7 +856,11 @@ class TestJobOutputFormatter:
         )
 
         uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
-        rich_cmp(JobStatusFormatter(uri_formatter=uri_fmtr)(description))
+        rich_cmp(
+            JobStatusFormatter(
+                uri_formatter=uri_fmtr, datetime_formatter=format_datetime_human
+            )(description)
+        )
 
     def test_job_with_volumes_long(self, rich_cmp: Any) -> None:
         description = JobDescription(
@@ -787,7 +909,11 @@ class TestJobOutputFormatter:
             pass_config=True,
         )
 
-        rich_cmp(JobStatusFormatter(uri_formatter=str)(description))
+        rich_cmp(
+            JobStatusFormatter(
+                uri_formatter=str, datetime_formatter=format_datetime_human
+            )(description)
+        )
 
     def test_job_with_secrets_short(self, rich_cmp: Any) -> None:
         description = JobDescription(
@@ -852,7 +978,11 @@ class TestJobOutputFormatter:
         )
 
         uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
-        rich_cmp(JobStatusFormatter(uri_formatter=uri_fmtr)(description))
+        rich_cmp(
+            JobStatusFormatter(
+                uri_formatter=uri_fmtr, datetime_formatter=format_datetime_human
+            )(description)
+        )
 
     def test_job_with_disk_volumes_short(self, rich_cmp: Any) -> None:
         description = JobDescription(
@@ -907,7 +1037,11 @@ class TestJobOutputFormatter:
         )
 
         uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
-        rich_cmp(JobStatusFormatter(uri_formatter=uri_fmtr)(description))
+        rich_cmp(
+            JobStatusFormatter(
+                uri_formatter=uri_fmtr, datetime_formatter=format_datetime_human
+            )(description)
+        )
 
     def test_job_with_working_dir(self, rich_cmp: Any) -> None:
         description = JobDescription(
@@ -946,7 +1080,11 @@ class TestJobOutputFormatter:
         )
 
         uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
-        rich_cmp(JobStatusFormatter(uri_formatter=uri_fmtr)(description))
+        rich_cmp(
+            JobStatusFormatter(
+                uri_formatter=uri_fmtr, datetime_formatter=format_datetime_human
+            )(description)
+        )
 
     def test_job_with_preset_name(self, rich_cmp: Any) -> None:
         description = JobDescription(
@@ -975,7 +1113,11 @@ class TestJobOutputFormatter:
         )
 
         uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
-        rich_cmp(JobStatusFormatter(uri_formatter=uri_fmtr)(description))
+        rich_cmp(
+            JobStatusFormatter(
+                uri_formatter=uri_fmtr, datetime_formatter=format_datetime_human
+            )(description)
+        )
 
     def test_job_on_preemptible_node(self, rich_cmp: Any) -> None:
         description = JobDescription(
@@ -1004,42 +1146,116 @@ class TestJobOutputFormatter:
         )
 
         uri_fmtr = uri_formatter(username="test-user", cluster_name="test-cluster")
-        rich_cmp(JobStatusFormatter(uri_formatter=uri_fmtr)(description))
+        rich_cmp(
+            JobStatusFormatter(
+                uri_formatter=uri_fmtr, datetime_formatter=format_datetime_human
+            )(description)
+        )
 
 
 class TestJobTelemetryFormatter:
     # Use utc timezone in test for stable constant result
 
     def test_format_telemetry_line_no_gpu(
-        self, rich_cmp: Any, new_console: _NewConsole
+        self, job_descr: JobDescription, rich_cmp: Any, new_console: _NewConsole
     ) -> None:
         console = new_console(tty=True, color=True)
-        with JobTelemetryFormatter(console, timezone.utc) as fmt:
+        with JobTelemetryFormatter(
+            console, datetime_formatter=format_datetime_human
+        ) as fmt:
             timestamp = 1_517_248_466.238_723_6
             telemetry = JobTelemetry(cpu=0.12345, memory=256.123, timestamp=timestamp)
             # Use utc timezone in test for stable constant result
-            fmt.update(telemetry)
+            fmt.update(job_descr, telemetry)
+            assert fmt.changed
+            fmt.render()
+            assert not fmt.changed
             rich_cmp(console)
 
     def test_format_telemetry_seq(
-        self, rich_cmp: Any, new_console: _NewConsole
+        self, job_descr: JobDescription, rich_cmp: Any, new_console: _NewConsole
     ) -> None:
         console = new_console(tty=True, color=True)
-        with JobTelemetryFormatter(console, timezone.utc) as fmt:
+        with JobTelemetryFormatter(
+            console, datetime_formatter=format_datetime_human
+        ) as fmt:
             timestamp = 1_517_248_466.238_723_6
             telemetry = JobTelemetry(cpu=0.12345, memory=256.123, timestamp=timestamp)
-            fmt.update(telemetry)
+            fmt.update(job_descr, telemetry)
+            assert fmt.changed
+            fmt.render()
+            assert not fmt.changed
             rich_cmp(console, index=0)
+
             timestamp = 1_517_248_467.238_723_6
             telemetry = JobTelemetry(cpu=0.23456, memory=128.123, timestamp=timestamp)
-            fmt.update(telemetry)
+            fmt.update(job_descr, telemetry)
+            assert fmt.changed
+            fmt.render()
+            assert not fmt.changed
+            rich_cmp(console, index=1)
+
+    def test_format_telemetry_multiple_jobs(
+        self, job_descr: JobDescription, rich_cmp: Any, new_console: _NewConsole
+    ) -> None:
+        job_descr2 = replace(job_descr, id=TEST_JOB_ID2)
+        console = new_console(tty=True, color=True)
+        with JobTelemetryFormatter(
+            console, datetime_formatter=format_datetime_human
+        ) as fmt:
+            timestamp = 1_517_248_466.238_723_6
+            telemetry = JobTelemetry(cpu=0.12345, memory=256.123, timestamp=timestamp)
+            fmt.update(job_descr, telemetry)
+            assert fmt.changed
+            fmt.render()
+            assert not fmt.changed
+            rich_cmp(console, index=0)
+
+            timestamp = 1_517_248_467.238_723_6
+            telemetry = JobTelemetry(cpu=0.23456, memory=128.123, timestamp=timestamp)
+            fmt.update(job_descr2, telemetry)
+            assert fmt.changed
+            fmt.render()
+            assert not fmt.changed
+            rich_cmp(console, index=1)
+
+            fmt.remove(job_descr2.id)
+            assert fmt.changed
+            fmt.render()
+            assert not fmt.changed
+            rich_cmp(console, index=2)
+
+    def test_format_telemetry_limited_height(
+        self, job_descr: JobDescription, rich_cmp: Any, new_console: _NewConsole
+    ) -> None:
+        job_descr2 = replace(job_descr, id=TEST_JOB_ID2)
+        console = new_console(tty=True, color=True)
+        with JobTelemetryFormatter(
+            console, maxrows=1, datetime_formatter=format_datetime_human
+        ) as fmt:
+            timestamp = 1_517_248_466.238_723_6
+            telemetry = JobTelemetry(cpu=0.12345, memory=256.123, timestamp=timestamp)
+            fmt.update(job_descr, telemetry)
+            assert fmt.changed
+            fmt.render()
+            assert not fmt.changed
+            rich_cmp(console, index=0)
+
+            timestamp = 1_517_248_467.238_723_6
+            telemetry = JobTelemetry(cpu=0.23456, memory=128.123, timestamp=timestamp)
+            fmt.update(job_descr2, telemetry)
+            assert fmt.changed
+            fmt.render()
+            assert not fmt.changed
             rich_cmp(console, index=1)
 
     def test_format_telemetry_line_with_gpu(
-        self, rich_cmp: Any, new_console: _NewConsole
+        self, job_descr: JobDescription, rich_cmp: Any, new_console: _NewConsole
     ) -> None:
         console = new_console(tty=True, color=True)
-        with JobTelemetryFormatter(console, timezone.utc) as fmt:
+        with JobTelemetryFormatter(
+            console, datetime_formatter=format_datetime_human
+        ) as fmt:
             timestamp = 1_517_248_466
             telemetry = JobTelemetry(
                 cpu=0.12345,
@@ -1048,7 +1264,10 @@ class TestJobTelemetryFormatter:
                 gpu_duty_cycle=99,
                 gpu_memory=64.5,
             )
-            fmt.update(telemetry)
+            fmt.update(job_descr, telemetry)
+            assert fmt.changed
+            fmt.render()
+            assert not fmt.changed
             rich_cmp(console)
 
 
@@ -1182,6 +1401,7 @@ class TestTabularJobRow:
             self._job_descr_with_status(JobStatus.RUNNING, name="job-name"),
             "owner",
             image_formatter=str,
+            datetime_formatter=format_datetime_human,
         )
         assert row.name == "job-name"
 
@@ -1190,6 +1410,7 @@ class TestTabularJobRow:
             self._job_descr_with_status(JobStatus.RUNNING, name=None),
             "owner",
             image_formatter=str,
+            datetime_formatter=format_datetime_human,
         )
         assert row.name == ""
 
@@ -1207,7 +1428,10 @@ class TestTabularJobRow:
         self, status: JobStatus, date: str, color: str
     ) -> None:
         row = TabularJobRow.from_job(
-            self._job_descr_with_status(status), "owner", image_formatter=str
+            self._job_descr_with_status(status),
+            "owner",
+            image_formatter=str,
+            datetime_formatter=format_datetime_human,
         )
         assert row.status == Text(status, style="color")
         assert row.when == date
@@ -1222,6 +1446,7 @@ class TestTabularJobRow:
             ),
             "bob",
             image_formatter=image_fmtr,
+            datetime_formatter=format_datetime_human,
         )
         assert row.image == "image:swiss-box:red"
         assert row.name == ""
@@ -1234,6 +1459,7 @@ class TestTabularJobRow:
             ),
             "owner",
             image_formatter=str,
+            datetime_formatter=format_datetime_human,
         )
         assert row.image == "image://test-cluster/bob/swiss-box:red"
         assert row.name == ""
@@ -1257,7 +1483,10 @@ class TestTabularJobsFormatter:
 
     def test_empty(self, rich_cmp: Any) -> None:
         formatter = TabularJobsFormatter(
-            "owner", parse_columns(None), image_formatter=str
+            "owner",
+            parse_columns(None),
+            image_formatter=str,
+            datetime_formatter=format_datetime_human,
         )
         rich_cmp(formatter([]))
 
@@ -1292,7 +1521,10 @@ class TestTabularJobsFormatter:
             pass_config=True,
         )
         formatter = TabularJobsFormatter(
-            "owner", parse_columns(None), image_formatter=str
+            "owner",
+            parse_columns(None),
+            image_formatter=str,
+            datetime_formatter=format_datetime_human,
         )
         rich_cmp(formatter([job]), index=idx)
 
@@ -1367,7 +1599,10 @@ class TestTabularJobsFormatter:
             ),
         ]
         formatter = TabularJobsFormatter(
-            "owner", parse_columns(None), image_formatter=str
+            "owner",
+            parse_columns(None),
+            image_formatter=str,
+            datetime_formatter=format_datetime_human,
         )
         rich_cmp(formatter(jobs), index=idx)
 
@@ -1398,7 +1633,12 @@ class TestTabularJobsFormatter:
         )
 
         columns = parse_columns("{status;align=right;min=20;Status Code}")
-        formatter = TabularJobsFormatter("owner", columns, image_formatter=str)
+        formatter = TabularJobsFormatter(
+            "owner",
+            columns,
+            image_formatter=str,
+            datetime_formatter=format_datetime_human,
+        )
         rich_cmp(formatter([job]))
 
     def test_life_span(self, rich_cmp: Any) -> None:
@@ -1433,7 +1673,12 @@ class TestTabularJobsFormatter:
         ]
 
         columns = parse_columns("id life_span")
-        formatter = TabularJobsFormatter("owner", columns, image_formatter=str)
+        formatter = TabularJobsFormatter(
+            "owner",
+            columns,
+            image_formatter=str,
+            datetime_formatter=format_datetime_human,
+        )
         rich_cmp(formatter(jobs))
 
     def test_dates(self, rich_cmp: Any) -> None:
@@ -1493,7 +1738,12 @@ class TestTabularJobsFormatter:
         ]
 
         columns = parse_columns("id status when created started finished")
-        formatter = TabularJobsFormatter("test-user", columns, image_formatter=str)
+        formatter = TabularJobsFormatter(
+            "test-user",
+            columns,
+            image_formatter=str,
+            datetime_formatter=format_datetime_human,
+        )
         rich_cmp(formatter(jobs))
 
     def test_working_dir(self, rich_cmp: Any) -> None:
@@ -1528,5 +1778,50 @@ class TestTabularJobsFormatter:
         ]
 
         columns = parse_columns("id workdir")
-        formatter = TabularJobsFormatter("test-user", columns, image_formatter=str)
+        formatter = TabularJobsFormatter(
+            "test-user",
+            columns,
+            image_formatter=str,
+            datetime_formatter=format_datetime_human,
+        )
+        rich_cmp(formatter(jobs))
+
+    def test_preset(self, rich_cmp: Any) -> None:
+        items = [None, "cpu-small", "gpu-large"]
+        jobs = [
+            JobDescription(
+                status=JobStatus.FAILED,
+                owner="test-user",
+                cluster_name="default",
+                id=f"job-{i}",
+                uri=URL(f"job://default/test-user/job-{i}"),
+                description=None,
+                history=JobStatusHistory(
+                    status=JobStatus.FAILED,
+                    reason="ErrorReason",
+                    description="ErrorDesc",
+                    created_at=isoparse("2018-09-25T12:28:21.298672+00:00"),
+                    started_at=isoparse("2018-09-25T12:28:59.759433+00:00"),
+                    finished_at=datetime.now(timezone.utc) - timedelta(seconds=1),
+                ),
+                container=Container(
+                    command="test-command",
+                    image=RemoteImage.new_external_image(name="test-image"),
+                    resources=Resources(16, 0.1, 0, None, False, None, None),
+                ),
+                scheduler_enabled=False,
+                pass_config=True,
+                internal_hostname="host.local",
+                preset_name=preset_name,
+            )
+            for i, preset_name in enumerate(items, 1)
+        ]
+
+        columns = parse_columns("id preset")
+        formatter = TabularJobsFormatter(
+            "test-user",
+            columns,
+            image_formatter=str,
+            datetime_formatter=format_datetime_human,
+        )
         rich_cmp(formatter(jobs))
